@@ -47,8 +47,8 @@ class Client(object):
         self._meta = {}
         if self._username and self._password:
             self._login()
-        else:
-            raise ClientException('You must specify a username and password')
+        elif not self._api_key:
+            raise ClientException('You must specify a username and password or api key')
 
     def _request(self, path='', method='get', data=None, api_key=None, params={}):
         data = utils.api_request(self._api_url, path, method=method, \
